#
# spec file for package marvin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           marvin
Version:        0.2.7
Release:        1.1
Summary:        Scans a k8s cluster for misconfigurations and vulnerabilities
License:        Apache-2.0
URL:            https://github.com/undistro/marvin
Source:         marvin-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
Marvin is a CLI tool designed to help Kubernetes cluster administrators ensure
the security and reliability of their environments.

Using a comprehensive set of CEL (Common Expression Language) expressions,
Marvin performs extensive checks on cluster resources, identifying potential
issues, misconfigurations, and vulnerabilities that could pose a risk to the
system. It helps ensure that your Kubernetes clusters are always in compliance
with best practices and industry standards.

Marvin is also used as a plugin in Zora.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
    -X github.com/undistro/marvin/pkg/version.version=%{version} \
    -X github.com/undistro/marvin/pkg/version.commit=v%{version} \
    -X github.com/undistro/marvin/pkg/version.date=${BUILD_DATE}" \
   -o bin/marvin .

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Fri Oct 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.7:
  * bump alpine base image version from 3.19.1 to 3.20.3 (#66)
* Fri Sep 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.6:
  * UD-1664: Add check for unauthenticated or anonymous subjects
    within role bindings
* Thu Aug  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.5 (0.2.4 tag was messed up apparently):
  * fix: update Go version in Dockerfile (#64)
  * UD-1648: update tags to define floating tag in addition to
    version
  * bump Go version and k8s.io dependencies (#49)
  * add .github/dependabot.yml (#42)
  * run apk upgrade in Dockerfile (#43)
  * bump k8s.io dependencies from v0.29.2 to v0.29.3 (#41)
* Thu Apr 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- do not strip aka remove -s -w ldflags
* Tue Mar 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.3:
  * fix: handle compile errors (#40)
* Fri Mar 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.2:
  * Bump dependencies and Go version (#36)
  * Fix M-112 and use CEL optional values and variables in built-in
    checks (#39)
  * Check non-zero runAsUser in M-113 (#38)
  * Add CEL variables support (#37)
  * bump alpine base image to 3.19.1 (#35)
  * create MAINTAINERS.md (#34)
* Wed Jan 31 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.1:
  * bump k8s.io dependencies and update README.md (#33)
  * check for restartPolicy (#30)
  * checks for sudo in entrypoint & registry deprecated (#28)
  * Add new check for workload in namespace default (#25) (#26)
  * ci: bump github actions (#23)
  * Fix: CVEs on marvin container (#22)
  * docs: add RBAC section in README.md (#19)
  * Add CEL Playground link in README.md (#18)
* Wed Oct 25 2023 Johannes Kastl <kastl@b1-systems.de>
- new package marvin: Scans a k8s cluster to report potential
  issues, misconfigurations and vulnerabilities
